##
# Cookbook Name:: ziggrid
# Recipe:: ziggen
#
# Copyright (C) 2013 ZZiniki Infrastructure Software, LLC.
# 

include_recipe "ziggrid::shared"

ruby_block "announce that node is not ready" do
  block do
    node.set['ziggen']['is_node_ready'] = false
    node.save
  end
end

bluepill_service 'ziggen' do
  action :stop
end

# download ziggrid prod file only if it isn't already on the target system
local_data_file = File.join(Chef::Config[:file_cache_path], node[:ziggen][:data][:filename])

#download data file
remote_file local_data_file do
  source "#{node[:ziggen][:data][:base_url]}/#{node[:ziggen][:data][:filename]}"
  owner node[:ziggrid][:user]
  group node[:ziggrid][:group]
  mode "0755"
  action :create
end

deployDir = node[:ziggrid][:deploy_dir]

%w{data}.each do |dir|
  directory File.join(deployDir, dir) do
    mode 0755
    owner node[:ziggen][:user]
    group node[:ziggen][:group]
    action :create
    recursive true
  end
end

#configure log4j.properties
template File.join(deployDir, "logs", "ziggen-log4j.properties") do
  source "log4j.properties.erb"
  owner node[:ziggen][:user]
  group node[:ziggen][:group]
  mode 0644
  variables({
    :logFile           => File.join(deployDir, "logs", "ziggen.log"),
  })
end

#configure ziggrid-baseball.xml
template File.join(deployDir, "config", "ziggrid-baseball.xml") do
  source "ziggrid-baseball.xml.erb"
  owner node[:ziggen][:user]
  group node[:ziggen][:group]
  mode 0644
  variables({
    :couchUrl         => node[:ziggrid][:couchbase][:url],
    :couchBucket      => node[:ziggrid][:couchbase][:bucket],
    :dataDirectory    => File.join(deployDir, "data")
  })
end

#ziggrid data
execute "extract #{local_data_file}" do
  command "unzip -q -u -o #{local_data_file} -d #{deployDir}/data"
  user    node[:ziggen][:user]
  group   node[:ziggen][:group]
end

debugArguments = ""
if node[:ziggen][:debug]
  Chef::Log.info "Putting debug arguments into cluster startup command"
  debugArguments = "-Xdebug -Xrunjdwp:server=y,transport=dt_socket,address=4026,suspend=n"
end

java_command_array = [  
 
  "java",
  "-cp 'libs/*'",
  debugArguments,
  "-Dlog4j.debug",
  "-Dlog4j.configuration=file:#{File.join(deployDir, "logs", "ziggen-log4j.properties")}",
  "-Djava.util.logging.config.class=com.gmmapowell.utils.http.LoggingConfiguration",
  "-Dnet.spy.log.LoggerImpl=net.spy.memcached.compat.log.Log4JLogger",
  "-Dorg.ziniki.claim.endpoint=#{node[:ec2][:public_hostname]}",
  "org.ziggrid.generator.main.ZigGenerator", 
  "org.ziggrid.generator.out.json.LoadCouchbase",                     
  "file:#{File.join(deployDir, "config", "ziggrid-baseball.xml")}",
  "--server #{node[:ziggen][:webserver][:port]}",

]

java_command = java_command_array.join(' ')

Chef::Log.info "Configured java command as: #{java_command}"

#configure bluepill template
template "/etc/bluepill/ziggen.pill" do
  source "bluepill-config.pill.erb"
  owner node[:ziggrid][:user]
  group node[:ziggrid][:group]
  mode 0644
  variables({
    :user            => node[:ziggrid][:user],
    :group           => node[:ziggrid][:group],
    :command         => java_command,
    :workingDir      => "#{deployDir}",
    :appName         => "ziggen",
    :pidDir          => File.join(deployDir, "pid", "ziggen.pid")
  })
end

bluepill_service 'ziggen' do 
  action [:enable, :load, :restart]
end

ruby_block "announce that node is ready" do
  block do
    node.set['ziggen']['is_node_ready'] = true
    node.save
  end
end